# TokenServer
This Rails plugin creates a jwt (https://jwt.io) token. This created token is compatible with the Report-Server.

## Usage

## Installation
Add this line to your application's Gemfile:

```ruby
gem 'token_server'
```

Add this engine to your Rails project and mount it by adding the following line into your routes.rb:
```ruby
mount TokenServer::Engine => "token/"
```
Now you can access the token server via get "token/" authenticated with basic-authentication.

Now you need to configure the account class that you will use (you have to implement it by yourself!). The account class accesses the user and his rights in your system and adds all necessary data (roles and rights) into the User object that it returns:

Add this to your environment-files (like produrction.rb)
```ruby
TokenServer::account_class = "YOUR-ACCOUNT-CLASS"
config.token_secret = 'test_key'
```
The token secret is the shared secret used by the Report-Server and the token server. #TODO: Discuss whether it should be in the environment and not in the configuration..

This "YOUR-ACCOUNT-CLASS" is the name of the class that should look like this:

```ruby
module MyNameSpace
    class Account
        include ActiveModel::Model

        # Select different account models if necessary regarding to the sub-domain
        # (not used yet)
        def self.find_by(url_name: nil)
            Account.new
        end

        # Find user and check password. Return a user object that
        # contains the right information.
        def authenticate(user, password)

            # TODO: Fill me
            ::TokenServer::User.new(user_id: user, password: password, is_plugin_manager: true, credentials_hash: {})
        end
    end
end
```

Now you need to configure the built in knock gem (see: https://github.com/eilers/knock). Please copy this file from the Report-Server configuration: https://src2.imhosting.de/vrg/Report-Server/blob/master/config/initializers/knock.rb

This defines everything necessary to create the correct token.

Now execute:
```bash
$ bundle
```

Or install it yourself as:
```bash
$ gem install token_server
```

## Contributing
Contribution directions go here.

## License
The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).
